@@ -1,7 +1,20 @@
+# Copyright 2013 django-htmlmin authors. All rights reserved.
+# Use of this source code is governed by a BSD-style
+# license that can be found in the LICENSE file.
+
+
 class RequestMock(object):
 
     def __init__(self, path="/"):
         self.path = path
+        self._hit_htmlmin = True
+
+
+class RequestBareMock(object):
+
+    def __init__(self, path="/"):
+        self.path = path
+
 
 class ResponseMock(dict):
 
@@ -12,5 +25,7 @@ class ResponseMock(dict):
     status_code = 200
     content = "<html>   <body>some text here</body>    </html>"
 
+
 class ResponseWithCommentMock(ResponseMock):
-    content = "<html>   <!-- some comment --><body>some text here</body>    </html>"
+    content = "<html>   <!-- some comment --><body>some " + \
+              "text here</body>    </html>"
