@@ -1,13 +1,20 @@
 # -*- coding: utf-8 -*-
+
+# Copyright 2013 django-htmlmin authors. All rights reserved.
+# Use of this source code is governed by a BSD-style
+# license that can be found in the LICENSE file.
+
 '''
 File: pico_django.py
-Description: Code based on snippet available here: https://github.com/readevalprint/mini-django/blob/master/pico_django.py
+Description: Code based on snippet available in the link below.
+    https://github.com/readevalprint/mini-django/blob/master/pico_django.py
 '''
 
+from django.conf.urls import url
 from django.http import HttpResponse
-from django.conf.urls.defaults import patterns
 from htmlmin.decorators import minified_response, not_minified_response
 
+
 CONTENT = '''
 <html>
     <body>
@@ -17,18 +24,23 @@ CONTENT = '''
 </html>
     '''
 
+
 @minified_response
 def minified(request):
     return HttpResponse(CONTENT)
 
+
 @not_minified_response
 def not_minified(request):
     return HttpResponse(CONTENT)
 
+
 def raw(request):
     return HttpResponse(CONTENT)
 
-urlpatterns = patterns('',
-    (r'^min$', minified),
-    (r'^raw$', raw),
-    (r'^not_min$', not_minified))
+
+urlpatterns = [
+    url(r'^min$', minified),
+    url(r'^raw$', raw),
+    url(r'^not_min$', not_minified)
+]
